@@ -9,6 +9,12 @@ def pytest_addoption(parser):
         default=False,
         help="Re-generate all data_regression fixture data files.",
     )
+    group.addoption(
+        "--with-test-class-names",
+        action="store_true",
+        default=False,
+        help="Do not ignore the names of the test classes when composing the name of the regression data files.",
+    )
 
 
 @pytest.fixture
@@ -23,9 +29,9 @@ def data_regression(datadir, original_datadir, request):
     data directory.
 
     Subsequent runs against the same data will now compare against the generated file and pass
-    if the dicts are equal, or fail showing a diff otherwise. To regenerate the data,
+    if the dicts are equal, or fail showing a diff otherwise. To regenerate data for failed tests,
     either set `force_regen` attribute to True or pass the `--force-regen` flag to pytest
-    which will regenerate the data files for all tests. Make sure to diff the files to ensure
+    which will regenerate the data files for all failed tests. Make sure to diff the files to ensure
     the new changes are expected and not regressions.
 
     The dict may be anything serializable by the `yaml` library.
@@ -45,7 +51,7 @@ def dataframe_regression(datadir, original_datadir, request):
     """
     Example usage:
 
-    def testSomeData(num_regression):
+    def testSomeData(dataframe_regression):
         dataframe_regression.check(
             pandas.DataFrame.from_dict(
                 {
@@ -69,6 +75,35 @@ def dataframe_regression(datadir, original_datadir, request):
     return DataFrameRegressionFixture(datadir, original_datadir, request)
 
 
+@pytest.fixture
+def ndarrays_regression(datadir, original_datadir, request):
+    """
+    Similar to num_regression, but supports numpy arrays with arbitrary shape. The
+    dictionary is stored as an NPZ file. The values of the dictionary must be accepted
+    by ``np.asarray``.
+
+    Example::
+
+        def test_some_data(ndarrays_regression):
+            points, values = some_function()
+            ndarrays_regression.check(
+                {
+                    'points': points,  # array with shape (100, 3)
+                    'values': values,  # array with shape (100,)
+                },
+                default_tolerance=dict(atol=1e-8, rtol=1e-8)
+            )
+
+    :type embed_data: _EmbedDataFixture
+    :type request: FixtureRequest
+    :rtype: DataRegressionFixture
+    :return: Data regression fixture.
+    """
+    from .ndarrays_regression import NDArraysRegressionFixture
+
+    return NDArraysRegressionFixture(datadir, original_datadir, request)
+
+
 @pytest.fixture
 def file_regression(datadir, original_datadir, request):
     """
